==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/inputs/DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResourceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.inputs

import com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResourceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property s3Uri The Amazon S3 URI for the statistics resource.
 */
public data class DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResourceArgs(
    public val s3Uri: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResourceArgs> {
    override fun toJava():
        com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResourceArgs =
        com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResourceArgs.builder()
            .s3Uri(s3Uri?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResourceArgs].
 */
@PulumiTagMarker
public class DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResourceArgsBuilder internal
constructor() {
    private var s3Uri: Output<String>? = null

    /**
     * @param value The Amazon S3 URI for the statistics resource.
     */
    @JvmName("lgefqpshrrfktval")
    public suspend fun s3Uri(`value`: Output<String>) {
        this.s3Uri = value
    }

    /**
     * @param value The Amazon S3 URI for the statistics resource.
     */
    @JvmName("wngwkocdbokhvfmy")
    public suspend fun s3Uri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.s3Uri = mapped
    }

    internal fun build(): DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResourceArgs =
        DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResourceArgs(
            s3Uri = s3Uri,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/inputs/DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResourceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.inputs

import com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResourceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property s3Uri The Amazon S3 URI for the statistics resource.
 */
public data class DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResourceArgs(
    public val s3Uri: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResourceArgs> {
    override fun toJava(): com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResourceArgs =
        com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResourceArgs.builder()
            .s3Uri(s3Uri?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResourceArgs].
 */
@PulumiTagMarker
public class DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResourceArgsBuilder internal constructor() {
    private var s3Uri: Output<String>? = null

    /**
     * @param value The Amazon S3 URI for the statistics resource.
     */
    @JvmName("danewixvdpsfeist")
    public suspend fun s3Uri(`value`: Output<String>) {
        this.s3Uri = value
    }

    /**
     * @param value The Amazon S3 URI for the statistics resource.
     */
    @JvmName("jwkjofmgdfbepvgy")
    public suspend fun s3Uri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.s3Uri = mapped
    }

    internal fun build(): DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResourceArgs =
        DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResourceArgs(
            s3Uri = s3Uri,
        )
}
